@@ -14,7 +14,7 @@ use Carp 'croak';
 push @DBIx::Custom::CARP_NOT, __PACKAGE__;
 
 __PACKAGE__->attr(
-    [qw/param query_builder/],
+    [qw/param query_builder safety_column_name/],
     clause => sub { [] },
 );
 
@@ -75,6 +75,9 @@ sub _parse {
         croak qq{Each tag contains one column name: tag "$clause"}
           unless @$columns == 1;
         my $column = $columns->[0];
+        my $safety = $self->safety_column_name;
+        croak qq{"$column" is not safety column name}
+          unless $column =~ /$safety/;
         
         # Column count up
         my $count = ++$count->{$column};
@@ -117,14 +120,6 @@ DBIx::Custom::Where - Where clause
 
 =head1 ATTRIBUTES
 
-=head2 C<param>
-
-    my $param = $where->param;
-    $where    = $where->param({title => 'Perl',
-                               date => ['2010-11-11', '2011-03-05']},
-                               name => ['Ken', 'Taro']);
-=head1 METHODS
-
 =head2 C<clause>
 
     $where->clause(
@@ -136,6 +131,20 @@ If all parameter names is exists.
 
     "where ( {= title} and ( {< date} or {> date} ) )"
 
+=head2 C<param>
+
+    my $param = $where->param;
+    $where    = $where->param({title => 'Perl',
+                               date => ['2010-11-11', '2011-03-05']},
+                               name => ['Ken', 'Taro']);
+
+=head2 C<safety_column_name>
+
+    my $safety_column_name = $self->safety_column_name;
+    $dbi                   = $self->safety_column_name($name);
+
+=head1 METHODS
+
 =head2 C<to_string>
 
     $where->to_string;
